@@ -3,7 +3,7 @@ import subprocess
 
 from .config import host_role, current_role
 
-__all__ = ['ssh', 'all', 'uptime', 'upgrade']
+__all__ = ['ssh', 'all', 'uptime', 'upgrade', 'restart']
 
 @task
 def all():
